@@ -4,7 +4,8 @@ from jinja2 import Environment, FileSystemLoader, Template
 
 
 # set up the defaults
-
+# the name of the build dir
+BUILD_DIR = '_build'
 # exclude these directories and files
 EXCLUDED = (
     '_build',
